try_parse_time_zone

Function try_parse_time_zone 

pub fn try_parse_time_zone(input: &str) -> Result<TimeZone, TimeZoneParseError>
Parses a time zone from an IANA-shaped identifier or fixed offset with diagnostic errors.

Errors

Returns TimeZoneParseError when the input is empty, contains whitespace, is an invalid fixed offset, or is not an IANA-shaped identifier.