pub struct TimeZoneOffset { /* private fields */ }Expand description
A fixed UTC offset in signed minutes.
Implementations
Sourceimpl TimeZoneOffset
impl TimeZoneOffset
Sourcepub fn try_new(input: &str) -> Result<Self, TimeZoneParseError>
pub fn try_new(input: &str) -> Result<Self, TimeZoneParseError>
Parses a fixed time zone offset with diagnostic errors.
Errors
Returns TimeZoneParseError when the input is empty, contains whitespace,
is malformed, or falls outside the civil -14:00..=+14:00 range.
Sourcepub const fn from_minutes(minutes: i16) -> Option<Self>
pub const fn from_minutes(minutes: i16) -> Option<Self>
Returns an offset from signed minutes when it is in the civil range.
Sourcepub const fn total_minutes(self) -> i16
pub const fn total_minutes(self) -> i16
Returns the signed offset in minutes.